@@ -25,7 +25,7 @@
  * list of people on the gedit Team.  
  * See the ChangeLog files for a list of changes. 
  *
- * $Id: gedit-search-dialog.c,v 1.8 2006/11/19 17:02:16 pborelli Exp $
+ * $Id: gedit-search-dialog.c 5786 2007-08-12 12:36:30Z vgeddes $
  */
 
 #ifdef HAVE_CONFIG_H
@@ -123,28 +123,15 @@ gedit_search_dialog_get_property (GObject    *object,
 	}
 }
 
-static gboolean
-gedit_search_dialog_focus_in_event (GtkWidget     *widget,
-				    GdkEventFocus *event)
+void
+gedit_search_dialog_present_with_time (GeditSearchDialog *dialog,
+				       guint32            timestamp)
 {
-	gboolean res;
-	GeditSearchDialog *dlg = GEDIT_SEARCH_DIALOG (widget);
+	g_return_if_fail (GEDIT_SEARCH_DIALOG (dialog));
 
-	res = GTK_WIDGET_CLASS (gedit_search_dialog_parent_class)->focus_in_event (widget, event);
+	gtk_window_present_with_time (GTK_WINDOW (dialog), timestamp);
 
-	/*
-	 * If the document is focused and we print ctrl+F
-	 * we want the focus to go on the entry even if it
-	 * currently was on the Find button.
-	 */
-	if (!GTK_WIDGET_HAS_FOCUS (dlg->priv->search_text_entry))
-	{
-		gtk_widget_grab_focus (GTK_ENTRY (dlg->priv->search_text_entry));
-		gtk_editable_set_position (GTK_EDITABLE (dlg->priv->search_text_entry),
-					   -1);
-	}
-
-	return res;
+	gtk_widget_grab_focus (dialog->priv->search_text_entry);	
 }
 
 static gboolean
@@ -159,12 +146,10 @@ static void
 gedit_search_dialog_class_init (GeditSearchDialogClass *klass)
 {
 	GObjectClass *object_class = G_OBJECT_CLASS (klass);
-	GtkWidgetClass *widget_class = GTK_WIDGET_CLASS (klass);
 	GtkBindingSet *binding_set;
 	
 	object_class->set_property = gedit_search_dialog_set_property;
 	object_class->get_property = gedit_search_dialog_get_property;
-	widget_class->focus_in_event = gedit_search_dialog_focus_in_event;
 	
 	klass->show_replace = show_replace;
 	
@@ -332,6 +317,12 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 	gtk_dialog_add_buttons (GTK_DIALOG (dlg),
 				GTK_STOCK_CLOSE, GTK_RESPONSE_CANCEL,
 				NULL);
+				
+	/* HIG defaults */
+	gtk_container_set_border_width (GTK_CONTAINER (dlg), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->vbox), 2); /* 2 * 5 + 2 = 12 */
+	gtk_container_set_border_width (GTK_CONTAINER (GTK_DIALOG (dlg)->action_area), 5);
+	gtk_box_set_spacing (GTK_BOX (GTK_DIALOG (dlg)->action_area), 6);
 
 	ret = gedit_utils_get_glade_widgets (GEDIT_GLADEDIR "gedit-search-dialog.glade",
 					     "search_dialog_content",
@@ -352,13 +343,15 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 
 		gtk_box_pack_start_defaults (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 					     error_widget);
+		gtk_container_set_border_width (GTK_CONTAINER (error_widget), 5);					     
 
 		dlg->priv->glade_error = TRUE;
 
 		return;
 	}
 
-	dlg->priv->search_entry = gedit_history_entry_new ("gedit2_search_for_entry");
+	dlg->priv->search_entry = gedit_history_entry_new ("gedit2_search_for_entry",
+							   TRUE);
 	gtk_widget_set_size_request (dlg->priv->search_entry, 300, -1);
 	dlg->priv->search_text_entry = gedit_history_entry_get_entry
 			(GEDIT_HISTORY_ENTRY (dlg->priv->search_entry));
@@ -369,7 +362,8 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 				   dlg->priv->search_entry,
 				   1, 2, 0, 1);
 
-	dlg->priv->replace_entry = gedit_history_entry_new ("gedit2_replace_with_entry");
+	dlg->priv->replace_entry = gedit_history_entry_new ("gedit2_replace_with_entry",
+							    TRUE);
 	dlg->priv->replace_text_entry = gedit_history_entry_get_entry
 			(GEDIT_HISTORY_ENTRY (dlg->priv->replace_entry));
 	gtk_entry_set_activates_default (GTK_ENTRY (dlg->priv->replace_text_entry),
@@ -418,6 +412,7 @@ gedit_search_dialog_init (GeditSearchDialog *dlg)
 
 	gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dlg)->vbox),
 			    content, FALSE, FALSE, 0);
+	gtk_container_set_border_width (GTK_CONTAINER (content), 5);	     
 
 	g_signal_connect (dlg->priv->search_text_entry,
 			  "insert_text",
